---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

## 🐛🐛 Bug Report


### ⚗️ Current Behavior
A clear and concise description of the behavior.

**Input Code**
- REPL or Repo link if applicable:

```python
def function_wrong():
    pass
```

**Expected behavior/code**
A clear and concise description of what you expected to happen (or code).

```python
def function_right():
    # Here is the fix
    print("Ok)
    
```

### ⚙️ Environment

- `Python` version(s):
    - *good*: [e.g. 3.8]
    - **better**: [3.8.6 - Clang 12.0.0 (clang-1200.0.32.27)]
- `OS`: [e.g. Ubuntu 18.04, OSX 10.13.4, Windows 10]
- `IDE`: [Vim, VS-Code, PyCharm]
- `Packages`: [ `Tensorflow==2.1.2 - latest`]


### 🧰 Possible Solution  (optional)
<!--- Only if you have suggestions on a fix for the bug -->

### 🖼 Additional context/Screenshots (optional)
Add any other context about the problem here. If applicable, add screenshots to help explain.
